@@ -2,7 +2,7 @@ import os
 
 from .lib.sutils import *
 
-ROOT_DIR = Path(__file__).resolve().parent
+ROOT_DIR = Path(os.environ.get('PAMOGK_ROOT_DIR', __file__)).resolve().parent
 LIB_DIR = ROOT_DIR / 'lib'
 DATA_DIR = ROOT_DIR.parent / 'data'
 
